 ; The CMD file.
 ;
 ; Two parts: 1. Command definition and  2. State entry
 ; (state entry is after the commands def section)
 ;
 ; 1. Command definition
 ; ---------------------
 ; Note: The commands are CASE-SENSITIVE, and so are the command names.
 ; The eight directions are:
 ;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
 ;   corresponding to back, down-back, down, downforward, etc.
 ; The six buttons are:
 ;   a, b, c, x, y, z               (all lower case)
 ;   In default key config, abc are are the bottom, and xyz are on the
 ;   top row. For 2 button characters, we recommend you use a and b.
 ;   For 6 button characters, use abc for kicks and xyz for punches.
 ;
 ; Each [Command] section defines a command that you can use for
 ; state entry, as well as in the CNS file.
 ; The command section should look like:
 ;
 ;   [Command]
 ;   name = "some_name"
 ;   command = the_command
 ;   time = time (optional -- defaults to 15 if omitted)
 ;
 ; - some_name
 ;   A name to give that command. You'll use this name to refer to
 ;   that command in the state entry, as well as the CNS. It is case-
 ;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
 ;
 ; - command
 ;   list of buttons or directions, separated by commas.
 ;   Directions and buttons can be preceded by special characters:
 ;   slash (/) - means the key must be held down
 ;          egs. command = /D       ;hold the down direction
 ;               command = /F, a    ;hold fwd while you press a
 ;   tilde (~) - to detect key releases
 ;          egs. command = ~a       ;release the a button
 ;               command = ~D, F, a ;release down, press fwd, then a
 ;          If you want to detect "charge moves", you can specify
 ;          the time the key must be held down for (in game-ticks)
 ;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
 ;               command = ~30
 ;   dollar ($) - Direction-only: detect as 4-way
 ;          egs. command = $D       ;will detect if D, DB or DF is held
 ;               command = $B       ;will detect if B, DB or UB is held
 ;   plus (+) - Buttons only: simultaneous press
 ;          egs. command = a+b      ;press a and b at the same time
 ;               command = x+y+z    ;press x, y and z at the same time
 ;   You can combine them:
 ;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
 ;                                  ;then press a and b together
 ;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
 ;   you start off with a "release direction". This matches the way most
 ;   popular fighting games implement their engine.
 ;
 ; - time (optional)
 ;   Time allowed to do the command, given in game-ticks. Defaults to 15
 ;   if omitted
 ;
 ; If you have two or more commands with the same name, all of them will
 ; work. You can use it to allow multiple motions for the same move.
 ;
 ; Some common commands are given below. Delete, add, or modify as you wish.
 
 ;-| Super Motions |--------------------------------------------------------
 
 [Command];MvsC
 name = "SuperBoom2"
 command = ~D, DF, F, D, DF, F, x
 time = 30
 
 [Command];MvsC
 name = "SuperBoom2"
 command = ~D, DF, F, D, DF, F, y
 time = 30
 
 [Command];MvsC
 name = "SuperBoom2"
 command = ~D, DF, F, D, DF, F, z
 time = 30
 
 [Command];MvsC
 name = "SuperBoom"
 command = ~D, DB, B, D, DB, B, x
 time = 30
 
 [Command];MvsC
 name = "SuperBoom"
 command = ~D, DB, B, D, DB, B, y
 time = 30
 
 [Command];MvsC
 name = "SuperBoom"
 command = ~D, DB, B, D, DB, B, z
 time = 30
 

 ;-| Special Motions |------------------------------------------------------
 
; QCF_K
[Command]
name = "QCF_K"
command = ~D, DF, F, a

; QCF_K
[Command]
name = "QCF_K"
command = ~D, DF, F, b

; QCF_K
[Command]
name = "QCF_K"
command = ~D, DF, F, c


 [Command]
 name = "WAVE"
 command = ~D, DF, F, x
 time = 30
 
 [Command]
 name = "WAVE"
 command = ~D, DF, F, y
 time = 30
 
 [Command]
 name = "WAVE"
 command = ~D, DF, F, z
 time = 30
 
 [Command]
 name = "CANNON"
 command = ~D, DB, B, x
 time = 30
 
 [Command]
 name = "CANNON"
 command = ~D, DB, B, y
 time = 30
 
 [Command]
 name = "CANNON"
 command = ~D, DB, B, z
 time = 30
 

  ;-| Double Tap |-----------------------------------------------------------
 [Command]
 name = "FF";Required (do not remove)
 command = F, F
 time = 10
 
 [Command]
 name = "BB";Required (do not remove)
 command = B, B
 time = 10
 
 ;-| 2/3 Button Combination |-----------------------------------------------
 [Command]
 name = "recovery";Required (do not remove)
 command = a+b
 time = 1
 
 [Command]
 name = "ab"
 command = a+b
 time = 1
 
 ;-| Dir + Button |---------------------------------------------------------
 [Command]
 name = "fwd_a"
 command = /F,a
 time = 1
 
 [Command]
 name = "fwd_b"
 command = /F,b
 time = 1
 
 [Command]
 name = "fwd_c"
 command = /F,c
 time = 1
 
 [Command]
 name = "fwd_x"
 command = /F,x
 time = 1
 
 [Command]
 name = "fwd_y"
 command = /F,y
 time = 1
 
 [Command]
 name = "fwd_z"
 command = /F,z
 time = 1
 
 [Command]
 name = "back_a"
 command = /B,a
 time = 1
 
 [Command]
 name = "back_b"
 command = /B,b
 time = 1
 
 [Command]
 name = "back_c"
 command = /B,c
 time = 1
 
 [Command]
 name = "down_a"
 command = /$D,a
 time = 1
 
 [Command]
 name = "down_b"
 command = /$D,b
 time = 1
 
 [Command]
 name = "down_c"
 command = /$D,c
 time = 1
 
 [Command]
 name = "fwd_ab"
 command = /F, a+b
 time = 1
 
 [Command]
 name = "back_ab"
 command = /B, a+b
 time = 1
 
 ;-| Single Button |---------------------------------------------------------
 [Command]
 name = "a"
 command = a
 time = 1
 
 [Command]
 name = "b"
 command = b
 time = 1
 
 [Command]
 name = "c"
 command = c
 time = 1
 
 [Command]
 name = "x"
 command = x
 time = 1
 
 [Command]
 name = "y"
 command = y
 time = 1
 
 [Command]
 name = "z"
 command = z
 time = 1
 
 ;-| Hold Dir |--------------------------------------------------------------
 [Command]
 name = "holdfwd";Required (do not remove)
 command = /$F
 time = 1
 
 [Command]
 name = "holdback";Required (do not remove)
 command = /$B
 time = 1
 
 [Command]
 name = "holdup";Required (do not remove)
 command = /$U
 time = 1
 
 [Command]
 name = "holddown";Required (do not remove)
 command = /$D
 time = 1
 
 
 ;---------------------------------------------------------------------------
 ; 2. State entry
 ; --------------
 ; This is where you define what commands bring you to what states.
 ;
 ; Each state entry block looks like:
 ;   [State -1]                  ;Don't change this
 ;   type = ChangeState          ;Don't change this
 ;   value = new_state_number
 ;   trigger1 = command = "command_name"
 ;   . . .  (any additional triggers)
 ;
 ; - new_state_number is the number of the state to change to
 ; - command_name is the name of the command (from the section above)
 ; - Useful triggers to know:
 ;   - statetype
 ;       S, C or A : current state-type of player (stand, crouch, air)
 ;   - ctrl
 ;       0 or 1 : 1 if player has control. Unless "interrupting" another
 ;                move, you'll want ctrl = 1
 ;   - stateno
 ;       number of state player is in - useful for "move interrupts"
 ;   - movecontact
 ;       0 or 1 : 1 if player's last attack touched the opponent
 ;                useful for "move interrupts"
 ;
 ; Note: The order of state entry is important.
 ;   State entry with a certain command must come before another state
 ;   entry with a command that is the subset of the first.  
 ;   For example, command "fwd_a" must be listed before "a", and
 ;   "fwd_ab" should come before both of the others.
 ;
 ; For reference on triggers, see CNS documentation.
 ;
 ; Just for your information (skip if you're not interested):
 ; This part is an extension of the CNS. "State -1" is a special state
 ; that is executed once every game-tick, regardless of what other state
 ; you are in. 
 
 
 ; Don't remove the following line. It's required by the CMD standard.
 [Statedef -1]
 
 ;----------------
; we are immune to throw attack
[State -1]
type = NotHitBy
trigger1 = life > 0
value = C,NT

 ;----------------
; little trick
[State -1]
type = NotHitBy
trigger1 = life > 0
trigger1 = IsHelper = 0
trigger1 = p1name = "apocalypse"
value = SCA, HTP

;----------------
; we are hit
[State -1]
type = LifeAdd
trigger1 = NumHelper(009) = 1
trigger1 = IsHelper = 0
value = -30

 
;-----------------
;visor timer
[State -1]
type = VarAdd
trigger1 = Var(4) > 0
trigger1 = IsHelper = 0
V = 4
value = -1

;-----------------
;add power
[State -1]
type = poweradd
trigger1 = life > 0
trigger1 = IsHelper = 0
value = 10

;-----------------
;head caller
[State -1]
type = Helper
trigger1 = NumHelper(111) = 0
trigger1 = IsHelper = 0
trigger1 = p1name = "apocalypse"
trigger1 = stateno != 191
trigger1 = Time = 1
helpertype = normal
name = "head"
id = 111
postype = p1
pos = 0,0
stateno = 500
keyctrl = 0
ownpal = 0
priority = 1

;-----------------
;shoulder caller
[State -1]
type = Helper
trigger1 = NumHelper(301) = 0
trigger1 = IsHelper = 0
trigger1 = p1name = "apocalypse"
trigger1 = stateno != 191
trigger1 = Time = 1
helpertype = normal
name = "shoulder"
id = 301
postype = p1
pos = 0,0
stateno = 301
keyctrl = 0
ownpal = 0
priority = 1

;-----------------
;arm caller
[State -1]
type = Helper
trigger1 = NumHelper(302) = 0
trigger1 = IsHelper = 0
trigger1 = p1name = "apocalypse"
trigger1 = stateno != 191
trigger1 = Time = 1
helpertype = normal
name = "head"
id = 302
postype = p1
pos = 0,0
stateno = 302
keyctrl = 0
ownpal = 1
priority = 1

;-----------------
;punch caller
[State -1]
type = Helper
trigger1 = NumHelper(303) = 0
trigger1 = IsHelper = 0
trigger1 = p1name = "apocalypse"
trigger1 = stateno != 191
trigger1 = Time = 1
helpertype = normal
name = "head"
id = 303
postype = p1
pos = 0,0
stateno = 303
keyctrl = 0
ownpal = 1
priority = 1

[state -1]
type = destroyself
trigger1 = MatchOver = 1
trigger1 = parent,stateno = 5150
trigger1 = NumHelper(301) = 1
trigger1 = isHelper(301) = 1

[state -1]
type = destroyself
trigger1 = MatchOver = 1
trigger1 = parent,stateno = 5150
trigger1 = NumHelper(302) = 1
trigger1 = isHelper(302) = 1

[state -1]
type = destroyself
trigger1 = MatchOver = 1
trigger1 = parent,stateno = 5150
trigger1 = NumHelper(303) = 1
trigger1 = isHelper(303) = 1

[state -1]
type = destroyself
trigger1 = MatchOver = 1
trigger1 = parent,stateno = 5150
trigger1 = NumHelper(111) = 1
trigger1 = isHelper(111) = 1

 ;===========================================================================
 ;---------------------------------------------------------------------------
 ;hyper mega shock wave
 [State -1]
 type = ChangeState
 value = 3100
 triggerall = command = "SuperBoom2"
 triggerall = power >= 1000 ;Level 1 super
 triggerall = statetype = S
 trigger1 = ctrl = 1
 
 ;---------------------------------------------------------------------------
 ;BEAM
 [State -1]
 type = ChangeState
 value = 3000
 triggerall = command = "SuperBoom"
 triggerall = power >= 1000 ;Level 1 super
 triggerall = statetype = S
 trigger1 = ctrl = 1

 ;---------------------------------------------------------------------------
 ;WAVE 
 [State -1]
 type = ChangeState
 value = 3200
 triggerall = command = "WAVE"
 triggerall = statetype = S
 trigger1 = ctrl = 1
 
 ;---------------------------------------------------------------------------
 ;CANNON
 [State -1]
 type = ChangeState
 value = 430
 triggerall = command = "CANNON"
 triggerall = statetype = S
 trigger1 = ctrl = 1
 
  ;---------------------------------------------------------------------------
 ;drill
 [State -1]
 type = ChangeState
 value = 420
 triggerall = statetype = S
 triggerall = ctrl = 1
 trigger1 = command = "QCF_K"
 

 ;---------------------------------------------------------------------------
 ;RunFwd
 [State -1]
 type = ChangeState
 value = 100
 trigger1 = command = "FF"
 trigger1 = statetype = S
 trigger1 = ctrl = 1
 
 ;---------------------------------------------------------------------------
 ;RunBack
 [State -1]
 type = ChangeState
 value = 105
 trigger1 = command = "BB"
 trigger1 = statetype = S
 trigger1 = ctrl = 1
 
 
 ;===========================================================================
 ;---------------------------------------------------------------------------
 ;punch
 [State -1]
 type = ChangeState
 value = 400
 triggerall = statetype = S
 triggerall = ctrl = 1
 trigger1 = command = "x"
 trigger2 = command = "y"
 trigger3 = command = "z"

  ;---------------------------------------------------------------------------
 ;spike
 [State -1]
 type = ChangeState
 value = 410
 triggerall = statetype = S
 triggerall = ctrl = 1
 trigger1 = command = "a"
 trigger2 = command = "b"
 trigger3 = command = "c"

 ;---------------------------------------------------------------------------
 ;forward
 [State -1]
 type = Velset
 triggerall = statetype = S
 triggerall = ctrl = 1
 trigger1 = command = "holdfwd"
 trigger1 = stateno != 100
 x = 2.3

 ;---------------------------------------------------------------------------
 ;backward
 [State -1]
 type = Velset
 triggerall = statetype = S
 triggerall = ctrl = 1
 trigger1 = command = "holdback"
 trigger1 = stateno != 106
x = -2.2
